﻿namespace Cop.Borovkov.Var3.Components
{
    public partial class CustomListBox : UserControl
    {
        private event EventHandler? _valueChanged;
        private event Action<Exception>? _errorOccured;

        /// <summary>
        /// </summary>
        public CustomListBox()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Событие возникающие при изменении списка
        /// </summary>
        public event EventHandler ValueChanged
        {
            add => _valueChanged += value;
            remove => _valueChanged -= value;
        }

        /// <summary>
        /// Обработка ошибок
        /// </summary>
        public event Action<Exception> AnErrorOccurred
        {
            add => _errorOccured += value;
            remove => _errorOccured -= value;
        }

        /// <summary>
        /// Заполнить список значениями
        /// </summary>
        /// <param name="strings">Список значений</param>
        public void FillValues(IEnumerable<string> strings)
        {
            InerlistBox.Items.Clear();
            InerlistBox.Items.AddRange(strings.ToArray());
        }

        /// <summary>
        /// Очистить список
        /// </summary>
        public void Clear() => InerlistBox.Items.Clear();

        private void InerlistBox_ValueMemberChanged(object sender, EventArgs e)
        {
            try
            {
                _valueChanged?.Invoke(sender, e);
            }
            catch (Exception ex) 
            {
                _errorOccured?.Invoke(ex);   
            }
        }

        /// <summary>
        /// Выбранное значение
        /// </summary>
        public string Selected
        {
            get => (string?)InerlistBox.SelectedItem ?? string.Empty;
            set => InerlistBox.SelectedItem = value;
        }
    }
}
